OC.L10N.register(
    "core",
    {
    "Please select a file." : "Lütfen bir dosya seçin.",
    "File is too big" : "Dosya çok büyük",
    "The selected file is not an image." : "Seçilmiş dosya bir görsel dosyası değil.",
    "The selected file cannot be read." : "Seçilmiş dosya okunamadı.",
    "The file was uploaded" : "Dosya yüklendi",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Yüklenen dosya php.ini dosyasındaki yüklenebilecek dosya boyutunu belirten upload_max_filesize değişkeninin değerini aşıyor",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Yüklenen dosya HTML formundaki yüklenebilecek dosya boyutunu belirten MAX_FILE_SIZE değişkeninin değerini aşıyor",
    "The file was only partially uploaded" : "Dosyanın yalnızca bir bölümü yüklendi",
    "No file was uploaded" : "Herhangi bir dosya yüklenmedi",
    "Missing a temporary folder" : "Bir geçici klasör eksik",
    "Could not write file to disk" : "Dosya diske yazılamadı",
    "A PHP extension stopped the file upload" : "Bir PHP eklentisi dosyanın yüklenmesini engelledi",
    "Invalid file provided" : "Belirtilen dosya geçersiz",
    "No image or file provided" : "Bir görsel ya da dosya belirtilmemiş",
    "Unknown filetype" : "Dosya türü bilinmiyor",
    "An error occurred. Please contact your admin." : "Bir sorun çıktı. Lütfen yöneticiniz ile görüşün.",
    "Invalid image" : "Görsel geçersiz",
    "No temporary profile picture available, try again" : "Kullanılabilecek geçici bir profil görseli bulunamadı. Yeniden deneyin",
    "No crop data provided" : "Kırpma verileri belirtilmemiş",
    "No valid crop data provided" : "Geçerli bir kırpma verisi belirtilmemiş",
    "Crop is not square" : "Kırpma kare şeklinde değil",
    "State token does not match" : "Durum kodu eşleşmiyor",
    "Invalid app password" : "Uygulama parolası geçersiz",
    "Could not complete login" : "Oturum açılamadı",
    "State token missing" : "Durum kodu eksik",
    "Your login token is invalid or has expired" : "Oturum açma kodunuz geçersiz ya da geçerlilik süresi dolmuş",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Bu Nextcloud topluluk sürümü desteklenmiyor ve anlık bildirimler sınırlı şekilde kullanılabiliyor.",
    "Login" : "Oturum aç",
    "Unsupported email length (>255)" : "E-posta uzunluğu desteklenmiyor (>255)",
    "Password reset is disabled" : "Parola sıfırlama özelliği kapatılmış",
    "Could not reset password because the token is expired" : "Kodun geçerlilik süresi dolmuş olduğundan parola sıfırlanamadı",
    "Could not reset password because the token is invalid" : "Kod geçersiz olduğundan parola sıfırlanamadı",
    "Password is too long. Maximum allowed length is 469 characters." : "Parola çok uzun. En fazla 469 karakter uzunluğunda olabilir.",
    "%s password reset" : "%s parola sıfırlama",
    "Password reset" : "Parolamı sıfırla",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Parolanızı sıfırlamak için düğmeye tıklayın. Parola sıfırlama isteğinde bulunmadıysanız bu e-postayı yok sayabilirsiniz.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Parolanızı sıfırlamak için bağlantıya tıklayın. Parola sıfırlama isteğinde bulunmadıysanız bu e-postayı yok sayabilirsiniz.",
    "Reset your password" : "Parolamı sıfırla",
    "The given provider is not available" : "Belirtilen hizmet sağlayıcı kullanılamıyor",
    "Task not found" : "Görev bulunamadı",
    "Internal error" : "İçeride bir sorun çıktı",
    "Not found" : "Bulunamadı",
    "Bad request" : "İstek hatalı",
    "Requested task type does not exist" : "İstenilen görev türü bulunamadı",
    "Necessary language model provider is not available" : "Gerekli dil modeli sağlayıcısı kullanılamıyor",
    "No text to image provider is available" : "Kullanılabilecek bir yazıdan görsel oluşturma hizmeti sağlayıcısı yok",
    "Image not found" : "Görsel bulunamadı",
    "No translation provider available" : "Kullanılabilecek bir çeviri hizmeti sağlayıcı yok",
    "Could not detect language" : "Dil algılanamadı",
    "Unable to translate" : "Çevrilemedi",
    "Nextcloud Server" : "Nextcloud sunucusu",
    "Some of your link shares have been removed" : "Bazı paylaşım bağlantılarınız silindi",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Bir güvenlik açığı nedeniyle bazı paylaşım bağlantılarınızı silmek zorunda kaldık. ayrıntılı bilgi almak için bağlantıya bakabilirsiniz.",
    "The account limit of this instance is reached." : "Bu kopya için hesap sayısı sınırına ulaşıldı.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Hesap sayısı sınırını artırmak için destek uygulamasına abonelik kodunuzu yazın. Bu ayrıca size Nextcloud Enterprise sürümünün sunduğu ve kurumsal operasyonlar için önemle önerilen tüm ek faydaları sağlar.",
    "Learn more ↗" : "Ayrıntılı bilgi alın ↗",
    "Preparing update" : "Güncelleme hazırlanıyor",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Onarım adımı:",
    "Repair info:" : "Onarım bilgileri:",
    "Repair warning:" : "Onarım uyarısı:",
    "Repair error:" : "Onarım sorunu:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Tarayıcı üzerinden güncelleme config.php dosyasında kullanımdan kaldırılmış olduğundan, komut satırı güncelleyicisini kullanın.",
    "Turned on maintenance mode" : "Bakım kipi kullanıma alındı",
    "Turned off maintenance mode" : "Bakım kipi kullanımdan kaldırıldı",
    "Maintenance mode is kept active" : "Bakım kipi kullanımda tutuldu",
    "Updating database schema" : "Veri tabanı şeması güncelleniyor",
    "Updated database" : "Veri tabanı güncellendi",
    "Update app \"%s\" from App Store" : "Uygulama mağazasından \"%s\" uygulamasını güncelle",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "%s için veri tabanı şeması güncellemesi denetleniyor (veri tabanının büyüklüğüne bağlı olarak uzun sürebilir)",
    "Updated \"%1$s\" to %2$s" : "\"%1$s\", %2$s sürümüne güncellendi",
    "Set log level to debug" : "Günlük kaydı düzeyi hata ayıklama olarak ayarlanıyor",
    "Reset log level" : "Günlük kaydı düzeyi sıfırlanıyor",
    "Starting code integrity check" : "Kod bütünlüğü sınaması başlatılıyor",
    "Finished code integrity check" : "Kod bütünlüğü sınaması tamamlandı",
    "%s (incompatible)" : "%s (uyumsuz)",
    "The following apps have been disabled: %s" : "Şu uygulamalar kullanımdan kaldırıldı: %s",
    "Already up to date" : "Zaten güncel",
    "Error occurred while checking server setup" : "Sunucu ayarları denetlenirken sorun çıktı",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Ayrıntılı bilgi almak için {linkstart}belgeler ↗{linkend} bölümüne bakabilirsiniz.",
    "unknown text" : "bilinmeyen metin",
    "Hello world!" : "Merhaba dünya!",
    "sunny" : "güneşli",
    "Hello {name}, the weather is {weather}" : "Merhaba {name}, hava durumu {weather}",
    "Hello {name}" : "Merhaba {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Arama sonuçlarınız<script>alert(1)</script></strong>",
    "new" : "yeni",
    "_download %n file_::_download %n files_" : ["%n dosya indiriliyor","%n dosya indiriliyor"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Güncelleniyor. Bu sayfadan ayrılırsanız bazı işlemler yarım kalabilir.",
    "Update to {version}" : "{version} sürümüne güncelleniyor",
    "An error occurred." : "Bir sorun çıktı.",
    "Please reload the page." : "Lütfen sayfayı yeniden yükleyin.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Uygulama güncellenemedi. Ayrıntılı bilgi almak için bu sorun ile ilgili <a href=\"{url}\">forum iletimize</a> bakabilirsiniz.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Uygulama güncellenemedi. Lütfen bu sorunu <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud topluluğuna</a> bildirin.",
    "Continue to {productName}" : "{productName} ile ilerle",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz.","Uygulama güncellendi. %n saniye içinde {productName} üzerine yönlendirileceksiniz."],
    "Applications menu" : "Uygulamalar menüsü",
    "Apps" : "Uygulamalar",
    "More apps" : "Diğer uygulamalar",
    "_{count} notification_::_{count} notifications_" : ["{count} bildirim","{count} bildirim"],
    "No" : "Hayır",
    "Yes" : "Evet",
    "The remote URL must include the user." : "Uzak adreste kullanıcı bulunmalıdır.",
    "Invalid remote URL." : "Uzak adres geçersiz.",
    "Failed to add the public link to your Nextcloud" : "Herkese açık bağlantı Nextcould üzerine eklenemedi",
    "Federated user" : "Birleşik kullanıcı",
    "user@your-nextcloud.org" : "kullanici@nextcloud-kopyaniz.org",
    "Create share" : "Paylaşım ekle",
    "Direct link copied to clipboard" : "Doğrudan bağlantı panoya kopyalandı",
    "Please copy the link manually:" : "Lütfen bağlantıyı el ile kopyalayın:",
    "Custom date range" : "Özel tarih aralığı",
    "Pick start date" : "Başlangıç tarihini seçin",
    "Pick end date" : "Bitiş tarihini seçin",
    "Search in date range" : "Tarih aralığında ara",
    "Search in current app" : "Geçerli uygulamada ara",
    "Clear search" : "Aramayı temizle",
    "Search everywhere" : "Her yerde ara",
    "Searching …" : "Aranıyor…",
    "Start typing to search" : "Aramak için yazmaya başlayın",
    "No matching results" : "Aramaya uyan bir sonuç bulunamadı",
    "Today" : "Bugün",
    "Last 7 days" : "Önceki 7 gün",
    "Last 30 days" : "Önceki 30 gün",
    "This year" : "Bu yıl",
    "Last year" : "Önceki yıl",
    "Unified search" : "Birleşik arama",
    "Search apps, files, tags, messages" : "Uygulama, dosya, etiket, ileti ara",
    "Places" : "Yerler",
    "Date" : "Tarih",
    "Search people" : "Kişi ara",
    "People" : "Kişiler",
    "Filter in current view" : "Geçerli görünümü süz",
    "Results" : "Sonuçlar",
    "Load more results" : "Diğer sonuçları yükle",
    "Search in" : "Şurada aransın",
    "Log in" : "Oturum aç",
    "Logging in …" : "Oturum açılıyor …",
    "Log in to {productName}" : "{productName} oturumu aç",
    "Wrong login or password." : "Hatalı kullanıcı adı ya da parolası.",
    "This account is disabled" : "Bu hesap kullanımdan kaldırılmış",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "IP adresinizden yapılan birden çok geçersiz oturum açma girişimi algılandı. Bu nedenle oturum açmanız 30 saniye süreyle engellendi.",
    "Account name or email" : "Hesap adı ya da e-posta adresi",
    "Account name" : "Hesap adı",
    "Server side authentication failed!" : "Kimlik sunucu tarafında doğrulanamadı!",
    "Please contact your administrator." : "Lütfen BT yöneticiniz ile görüşün.",
    "Temporary error" : "Geçici sorun",
    "Please try again." : "Lütfen yeniden deneyin.",
    "An internal error occurred." : "İçeride bir sorun çıktı.",
    "Please try again or contact your administrator." : "Lütfen yeniden deneyin ya da BT yöneticiniz ile görüşün.",
    "Password" : "Parola",
    "Log in with a device" : "Bir aygıt ile oturum açın",
    "Login or email" : "Kullanıcı adı ya da e-posta",
    "Your account is not setup for passwordless login." : "Hesabınız parola kullanmadan oturum açılacak şekilde ayarlanmamış.",
    "Your connection is not secure" : "Bağlantınız güvenli değil",
    "Passwordless authentication is only available over a secure connection." : "Parolasız kimlik doğrulama özelliği yalnızca güvenli bir bağlantı üzerinden kullanılabilir.",
    "Browser not supported" : "Tarayıcı desteklenmiyor!",
    "Passwordless authentication is not supported in your browser." : "Tarayıcınız parolasız kimlik doğrulama özelliğini desteklemiyor.",
    "Reset password" : "Parolayı sıfırla",
    "Back to login" : "Oturum açmaya geri dön",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Bu hesap varsa, e-posta adresine bir parola sıfırlama iletisi gönderilmiştir. Bunu almazsanız, e-posta adresinizi ve/veya kullanıcı adınızı doğrulayın, spam/önemsiz klasörlerinizi denetleyin ya da yerel yöneticinizden yardım isteyin.",
    "Couldn't send reset email. Please contact your administrator." : "Sıfırlama e-postası gönderilemedi. Lütfen BT yöneticiniz ile görüşün.",
    "Password cannot be changed. Please contact your administrator." : "Parola değiştirilemedi. Lütfen BT yöneticiniz ile görüşün.",
    "New password" : "Yeni parola",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Dosyalarınız şifrelendi. Parolanız sıfırlandıktan sonra verilerinizi geri almanın herhangi bir yolu olmayacak. Ne yapacağınızı bilmiyorsanız işlemi sürdürmeden önce BT yöneticiniz ile görüşün. İşlemi sürdürmek istediğinize emin misiniz? ",
    "I know what I'm doing" : "Ne yaptığımı biliyorum",
    "Resetting password" : "Parola sıfırlanıyor",
    "Schedule work & meetings, synced with all your devices." : "İşlerinizi ve toplantılarınızı planlayın ve tüm aygıtlarınızla eşitleyin.",
    "Keep your colleagues and friends in one place without leaking their private info." : "İş arkadaşlarınızın ve tanıdıklarınızın kayıtlarını kişisel bilgilerini sızdırmadan tek bir yerde tutun.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Dosyalar, Kişiler ve Takvim uygulamaları ile bir arada çalışan basit bir e-posta uygulaması.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri - masaüstü ve mobil için uygulamalar.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collabora Online üzerinde hazırlanmış iş birlikli çalışma belgeleri, hesap tabloları ve sunumlar.",
    "Distraction free note taking app." : "Dikkatinizi dağıtmayan not alma uygulaması.",
    "Recommended apps" : "Önerilen uygulamalar",
    "Loading apps …" : "Uygulamalar yükleniyor …",
    "Could not fetch list of apps from the App Store." : "Uygulama mağazasından uygulama listesi alınamadı.",
    "App download or installation failed" : "Uygulama indirilemedi ya da kurulamadı",
    "Cannot install this app because it is not compatible" : "Bu uygulama uyumlu olmadığından kurulamadı",
    "Cannot install this app" : "Bu uygulama kurulamadı",
    "Skip" : "Atla",
    "Installing apps …" : "Uygulamalar kuruluyor …",
    "Install recommended apps" : "Önerilen uygulamaları kur",
    "Avatar of {displayName}" : "{displayName} avatarı",
    "Settings menu" : "Ayarlar menüsü",
    "Loading your contacts …" : "Kişileriniz yükleniyor …",
    "Looking for {term} …" : "{term} ifadesi aranıyor …",
    "Search contacts" : "Kişi arama",
    "Reset search" : "Aramayı sıfırla",
    "Search contacts …" : "Kişi arama …",
    "Could not load your contacts" : "Kişileriniz yüklenemedi",
    "No contacts found" : "Herhangi bir kişi bulunamadı",
    "Show all contacts" : "Tüm kişileri görüntüle",
    "Install the Contacts app" : "Kişiler uygulamasını kur",
    "Search" : "Arama",
    "No results for {query}" : "{query} sorgusundan bir sonuç alınamadı",
    "Press Enter to start searching" : "Aramayı başlatmak için Enter tuşuna basın",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lütfen aramak için en az {minSearchLength} karakter yazın","Lütfen aramak için en az {minSearchLength} karakter yazın"],
    "An error occurred while searching for {type}" : "{type} aranırken bir sorun çıktı",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Arama, yazmaya başladığınızda başlar ve sonuçlara ok tuşları ile erişilebilir",
    "Search for {name} only" : "Yalnızca {name} için ara",
    "Loading more results …" : "Diğer sonuçlar yükleniyor…",
    "Forgot password?" : "Parolamı unuttum",
    "Back to login form" : "Oturum açma formuna dön",
    "Back" : "Geri",
    "Login form is disabled." : "Oturum açma formu kullanımdan kaldırılmış.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Nextcloud oturum açma formu kullanımdan kaldırılmış. Varsa başka bir oturum açma seçeneğini kullanın ya da yöneticiniz ile görüşün.",
    "More actions" : "Diğer işlemler",
    "Security warning" : "Güvenlik uyarısı",
    "Storage & database" : "Depolama ve veri tabanı",
    "Data folder" : "Veri klasörü",
    "Install and activate additional PHP modules to choose other database types." : "Diğer veri tabanı türlerini seçebilmek için ek PHP modüllerini kurun ve kullanıma alın.",
    "For more details check out the documentation." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz.",
    "Performance warning" : "Başarım uyarısı",
    "You chose SQLite as database." : "Veri tabanı olarak SQLite seçtiniz.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite yalnızca küçük ve geliştirme ortamları için seçilmelidir. Üretim ortamları için farklı bir veri tabanı kullanmanız önerilir.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Dosya eşitlemesi için istemcileri kullanıyorsanız SQLite kullanımından kaçınmalısınız.",
    "Database user" : "Veri tabanı kullanıcı adı",
    "Database password" : "Veri tabanı parolası",
    "Database name" : "Veri tabanı adı",
    "Database tablespace" : "Veri tabanı tablo alanı",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lütfen sunucu adının yanında bağlantı noktasını da belirtin (Örnek: localhost:5432).",
    "Database host" : "Veri tabanı sunucusu",
    "Installing …" : "Kuruluyor…",
    "Install" : "Kur",
    "Need help?" : "Yardım gerekiyor mu?",
    "See the documentation" : "Belgelere bakın",
    "{name} version {version} and above" : "{name} {version} üzeri sürümler",
    "This browser is not supported" : "Bu tarayıcı desteklenmiyor",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tarayıcınız desteklenmiyor. Lütfen daha yeni bir sürüme ya da desteklenen bir sürüme yükseltin.",
    "Continue with this unsupported browser" : "Bu desteklenmeyen tarayıcı ile ilerle",
    "Supported versions" : "Desteklenen sürümler",
    "Search {types} …" : "{types} arama…",
    "Choose {file}" : "{file} seçin",
    "Choose" : "Seçin",
    "Copy to {target}" : "{target} içine kopyala",
    "Copy" : "Kopyala",
    "Move to {target}" : "{target} içine taşı",
    "Move" : "Taşı",
    "OK" : "Tamam",
    "read-only" : "salt okunur",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} dosya çakışması","{count} dosya çakışması"],
    "One file conflict" : "Bir dosya çakışması",
    "New Files" : "Yeni dosyalar",
    "Already existing files" : "Zaten var olan dosyalar",
    "Which files do you want to keep?" : "Hangi dosyaları saklamak istiyorsunuz?",
    "If you select both versions, the copied file will have a number added to its name." : "İki sürümü de seçerseniz, kopyalanan dosyanın adına bir sayı eklenir.",
    "Cancel" : "İptal",
    "Continue" : "Sürdür",
    "(all selected)" : "(tüm seçilmişler)",
    "({count} selected)" : "({count} seçilmiş)",
    "Error loading file exists template" : "Dosya var kalıbı yüklenirken sorun çıktı",
    "Saving …" : "Kaydediliyor …",
    "seconds ago" : "saniyeler önce",
    "Connection to server lost" : "Sunucu bağlantısı kesildi",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek","Sayfa yüklenirken bir sorun çıktı. %n saniye sonra yeniden yüklenecek"],
    "Add to a project" : "Bir projeye ekle",
    "Show details" : "Ayrıntılar görüntülensin",
    "Hide details" : "Ayrıntılar gizlensin",
    "Rename project" : "Projeyi yeniden adlandır",
    "Failed to rename the project" : "Proje yeniden adlandırılamadı",
    "Failed to create a project" : "Bir proje eklenemedi",
    "Failed to add the item to the project" : "Öge projeye eklenemedi",
    "Connect items to a project to make them easier to find" : "Ögeleri bir projeye bağlayarak bulunmasını kolaylaştırın",
    "Type to search for existing projects" : "Var olan projeleri aramak için yazın",
    "New in" : "Şuraya ekle",
    "View changelog" : "Değişiklik günlüğünü görüntüle",
    "No action available" : "Yapılabilecek bir işlem yok",
    "Error fetching contact actions" : "Kişi işlemleri alınırken sorun çıktı",
    "Close \"{dialogTitle}\" dialog" : "\"{dialogTitle}\" penceresini kapat",
    "Email length is at max (255)" : "E-posta uzunluğu en fazla (255)",
    "Non-existing tag #{tag}" : "#{tag} etiketi bulunamadı",
    "Restricted" : "Kısıtlanmış",
    "Invisible" : "Görünmez",
    "Delete" : "Sil",
    "Rename" : "Yeniden adlandır",
    "Collaborative tags" : "İş birlikli etiketler",
    "No tags found" : "Herhangi bir etiket bulunamadı",
    "Clipboard not available, please copy manually" : "Pano kullanılamıyor. Lütfen el ile kopyalayın",
    "Personal" : "Kişisel",
    "Accounts" : "Hesaplar",
    "Admin" : "Yönetici",
    "Help" : "Yardım",
    "Access forbidden" : "Erişim engellendi",
    "Page not found" : "Sayfa bulunamadı",
    "The page could not be found on the server or you may not be allowed to view it." : "Sayfa sunucuda bulunamadı ya da görüntülemenize izin verilmiyor olabilir.",
    "Back to %s" : "%s sayfasına dön",
    "Too many requests" : "Çok fazla istekte bulunuldu",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Ağınızdan çok fazla istekte bulunuldu. Bir süre sonra yeniden deneyin ya da bir sorun olduğunu düşünüyorsanız BT yöneticiniz ile görüşün.",
    "Error" : "Hata",
    "Internal Server Error" : "Sunucuda bir sorun çıktı",
    "The server was unable to complete your request." : "Sunucu isteğinizi yerine getiremedi.",
    "If this happens again, please send the technical details below to the server administrator." : "Bu sorun sürerse lütfen aşağıdaki teknik ayrıntıları BT yöneticinize iletin.",
    "More details can be found in the server log." : "Sunucu günlüğünden ayrıntılı bilgi alabilirsiniz.",
    "For more details see the documentation ↗." : "Ayrıntılı bilgi almak için belgelere bakabilirsiniz ↗.",
    "Technical details" : "Teknik ayrıntılar",
    "Remote Address: %s" : "Uzak adres: %s",
    "Request ID: %s" : "İstek kimliği: %s",
    "Type: %s" : "Tür: %s",
    "Code: %s" : "Kod: %s",
    "Message: %s" : "İleti: %s",
    "File: %s" : "Dosya: %s",
    "Line: %s" : "Satır: %s",
    "Trace" : "İz",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Nextcloud kurulumunu yeniden yapmayı deniyorsunuz gibi görünüyor. Ancak config klasöründe CAN_INSTALL dosyası eksik. Lütfen İşlemi sürdürmek için config klasöründe CAN_INSTALL dosyasını oluşturun.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Config klasöründeki CAN_INSTALL dosyası silinemedi. Lütfen bu dosyayı el ile silin.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Bu uygulamanın düzgün çalışabilmesi için JavaScript gereklidir. Lütfen {linkstart}JavaScript uygulamasını kullanıma alıp{linkend} sayfayı yeniden yükleyin.",
    "Skip to main content" : "Ana içeriğe geç",
    "Skip to navigation of app" : "Uygulama gezinmesine geç",
    "Go to %s" : "%s bölümüne git",
    "Get your own free account" : "Ücretsiz hesabınızı açın",
    "Connect to your account" : "Hesabınızı bağlayın",
    "Please log in before granting %1$s access to your %2$s account." : "Lütfen %1$s için %2$s hesabınıza erişim izni vermeden önce oturum açın.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Yeni bir aygıt ya da uygulama kurmaya çalışmıyorsanız, başka biri verilerinize erişmek için sizi kandırmaya çalışıyor. Durum buysa daha ileri gitmeyin ve sistem yöneticiniz ile görüşün.",
    "App password" : "Uygulama parolası",
    "Grant access" : "Erişim izni ver",
    "Alternative log in using app password" : "Uygulama parolası ile alternatif oturum açma",
    "Account access" : "Hesap erişimi",
    "Currently logged in as %1$s (%2$s)." : "%1$s (%2$s) olarak oturum açıldı.",
    "You are about to grant %1$s access to your %2$s account." : "%1$s için %2$s hesabınıza erişim izni vermek üzeresiniz.",
    "Account connected" : "Hesap bağlandı",
    "Your client should now be connected!" : "İstemciniz şimdi bağlantı kurmuş olmalı!",
    "You can close this window." : "Bu pencereyi kapatabilirsiniz.",
    "Previous" : "Önceki",
    "This share is password-protected" : "Bu paylaşım parola korumalı",
    "The password is wrong or expired. Please try again or request a new one." : "Parola hatalı ya da geçerlilik süresi dolmuş. Lütfen yeniden deneyin ya da parolanızı değiştirin. ",
    "Please type in your email address to request a temporary password" : "Lütfen geçici parola isteğinde bulunmak için e-posta adresinizi yazın",
    "Email address" : "E-posta adresi",
    "Password sent!" : "Parola gönderildi!",
    "You are not authorized to request a password for this share" : "Bu paylaşım için parola isteğinde bulunma izniniz yok",
    "Two-factor authentication" : "İki adımlı doğrulama",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Hesabınız için gelişmiş güvenlik kullanıma alındı. Kimlik doğrulaması için bir ikinci aşama seçin:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kullanıma alınmış iki adımlı doğrulama yöntemlerinden en az biri yüklenemedi. Lütfen yöneticiniz ile görüşün.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "İki adımlı doğrulama kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yardım almak için sistem yöneticiniz ile görüşün.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "İki adımlı doğrulama kullanımı dayatılmış ancak hesabınız için yapılandırılması tamamlanmamış. Lütfen işlemi sürdürmek için iki adımlı doğrulamayı kurun.",
    "Set up two-factor authentication" : "İki adımlı doğrulama kurulumu",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "İki adımlı doğrulama kullanımı zorunlu kılınmış ancak hesabınız için yapılandırılmamış. Yedek kodlarınızdan birini kullanın ya da yardım almak için sistem yöneticiniz ile görüşün.",
    "Use backup code" : "Yedek kodu kullanacağım",
    "Cancel login" : "Oturum açmaktan vazgeç",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Hesabınız için gelişmiş güvenlik kullanımı dayatılmış. Kuracağınız hizmet sağlayıcıyı seçin:",
    "Error while validating your second factor" : "İkinci aşama doğrulanırken sorun çıktı",
    "Access through untrusted domain" : "Güvenilmeyen etki alanı üzerinden erişim",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Lütfen BT yöneticiniz ile görüşün. Yöneticisi siz iseniz, config/config.php dosyası içerisindeki \"trusted_domain\" ayarını config/config.sample.php dosyasındaki gibi düzenleyin.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Bu ayar ile ilgili ayrıntılı bilgi almak için %1$sbelgelere%2$s bakabilirsiniz.",
    "App update required" : "Uygulamanın güncellenmesi gerekli",
    "%1$s will be updated to version %2$s" : "%1$s, %2$s sürümüne güncellenecek",
    "The following apps will be updated:" : "Şu uygulamalar güncellenecek:",
    "These incompatible apps will be disabled:" : "Şu uyumsuz uygulamalar kullanımdan kaldırılacak:",
    "The theme %s has been disabled." : "%s teması kullanımdan kaldırıldı.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "İlerlemeden önce lütfen veri tabanı, yapılandırma klasörü ve veri klasörünün yedeklenmiş olduğundan emin olun.",
    "Start update" : "Güncellemeyi başlat",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Daha büyük kurulumlarda zaman aşımlarının önüne geçmek için, kurulum klasörünüzden şu komutu da çalıştırabilirsiniz:",
    "Detailed logs" : "Ayrıntılı günlükler",
    "Update needed" : "Güncelleme gerekiyor",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "50 üzerinde hesap bulunan bir kopya kullandığınız için lütfen komut satırı güncelleyiciyi kullanın.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Yardım almak için, <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">belgelere</a> bakın.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Güncellemeyi site arayüzü üzerinden yapmanın zaman aşımına neden olarak veri kaybına neden olabileceğini biliyorum. Ancak bir yedeğim var ve sorun çıkması durumunda nasıl geri yükleyebileceğimi biliyorum.",
    "Upgrade via web on my own risk" : "Riski alıyorum site arayüzünden güncelle",
    "Maintenance mode" : "Bakım kipi",
    "This %s instance is currently in maintenance mode, which may take a while." : "Bu %s kopyası şu anda bakım kipinde, bu işlem biraz zaman alabilir.",
    "This page will refresh itself when the instance is available again." : "Sistem yeniden kullanılabilir olduğunda bu sayfa kendiliğinden yenilenecek",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Bu ileti görüntülenmeyi sürdürüyor ya da beklenmedik şekilde ortaya çıkıyorsa BT yöneticiniz ile görüşün.",
    "Currently open" : "Şu anda açık",
    "Login with username or email" : "Kullanıcı adı ya da e-posta ile oturum açın",
    "Login with username" : "Kullanıcı adı ile oturum aç",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Sohbet, görüntülü çağrı, ekran paylaşımı, çevrim içi toplantılar ve internet görüşmeleri - masaüstü ve mobil için uygulamalar.",
    "You have not added any info yet" : "Henüz herhangi bir bilgi eklememişsiniz",
    "{user} has not added any info yet" : "{user} henüz herhangi bir bilgi eklememiş",
    "Error opening the user status modal, try hard refreshing the page" : "Üste açılan kullanıcı durumu penceresinde sorun çıktı. Sayfası temizleyerek yenilemeyi deneyin ",
    "Edit Profile" : "Profili düzenle",
    "The headline and about sections will show up here" : "Başlık ve hakkında bölümleri burada görüntülenir",
    "Error loading message template: {error}" : "İleti kalıbı yüklenirken sorun çıktı: {error}",
    "Very weak password" : "Parola çok zayıf",
    "Weak password" : "Parola zayıf",
    "So-so password" : "Parola idare eder",
    "Good password" : "Parola iyi",
    "Strong password" : "Parola güçlü",
    "Profile not found" : "Profil bulunamadı",
    "The profile does not exist." : "Profil bulunamadı.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : ".htaccess dosyası yürürlükte olmadığından veri klasörünüz ve dosyalarınız İnternet üzerinden erişime açık.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Sunucunuzu nasıl yapılandıracağınız hakkında bilgi almak için <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">belgelere</a> bakabilirsiniz.",
    "<strong>Create an admin account</strong>" : "<strong>Bir yönetici hesabı oluşturun</strong>",
    "New admin account name" : "Yeni yönetici hesabı adı",
    "New admin password" : "Yeni yönetici parolası",
    "Show password" : "Parolayı görüntüle",
    "Toggle password visibility" : "Parolayı görüntüle/gizle",
    "Configure the database" : "Veri tabanını yapılandır",
    "Only %s is available." : "Yalnızca %s kullanılabilir.",
    "Database account" : "Veri tabanı hesabı"
},
"nplurals=2; plural=(n > 1);");
